@@ -5,7 +5,8 @@ test_that("main function", {
   x <- generate_train_data()
   fit <- sGMRFmix(x, K = 7, rho = 100)
 
-  expect_equal(fit$pi, c(0.51, 0.49), tolerance = 1e-5)
+  expected <- c("1"=0.5156696, "2"=0.4843304)
+  expect_equal(fit$pi, expected, tolerance = 1e-7)
 })
 
 test_that("compute anomaly", {
@@ -14,5 +15,5 @@ test_that("compute anomaly", {
   fit <- sGMRFmix(x, K = 7, rho = 100)
   anomaly_score <- compute_anomaly_score(fit, generate_test_data())
 
-  expect_equal(anomaly_score[1, 1], 1.022136, tolerance = 1e-5)
+  expect_equal(anomaly_score[1, 1], 0.7737825, tolerance = 1e-7)
 })
